"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AddFileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FILE_NAME_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    FULL_PATH_FIELD_NUMBER: builtins.int
    file_name: typing.Text
    hash: typing.Text
    """hash of the file"""

    url: typing.Text
    full_path: typing.Text
    """full_path is the full path of the file on the local filesystem"""

    def __init__(self,
        *,
        file_name: typing.Text = ...,
        hash: typing.Text = ...,
        url: typing.Optional[typing.Text] = ...,
        full_path: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_url",b"_url","url",b"url"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_url",b"_url","file_name",b"file_name","full_path",b"full_path","hash",b"hash","url",b"url"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_url",b"_url"]) -> typing.Optional[typing_extensions.Literal["url"]]: ...
global___AddFileRequest = AddFileRequest

class CheckText(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IS_GOOGLE_ON_FIELD_NUMBER: builtins.int
    DOCUMENT_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    is_google_on: builtins.bool
    document: typing.Text
    user_id: builtins.int
    def __init__(self,
        *,
        is_google_on: builtins.bool = ...,
        document: typing.Text = ...,
        user_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["document",b"document","is_google_on",b"is_google_on","user_id",b"user_id"]) -> None: ...
global___CheckText = CheckText

class CheckTextResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class CheckResult(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        FILE_HASH_FIELD_NUMBER: builtins.int
        FILE_NAME_FIELD_NUMBER: builtins.int
        PLAGIARISM_PERCENTAGE_FIELD_NUMBER: builtins.int
        EXTENDED_DATA_FIELD_NUMBER: builtins.int
        file_hash: typing.Text
        file_name: typing.Text
        plagiarism_percentage: builtins.float
        extended_data: typing.Text
        def __init__(self,
            *,
            file_hash: typing.Text = ...,
            file_name: typing.Text = ...,
            plagiarism_percentage: builtins.float = ...,
            extended_data: typing.Text = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["extended_data",b"extended_data","file_hash",b"file_hash","file_name",b"file_name","plagiarism_percentage",b"plagiarism_percentage"]) -> None: ...

    USER_ID_FIELD_NUMBER: builtins.int
    CHECK_RESULT_ID_FIELD_NUMBER: builtins.int
    CHECK_RESULT_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    check_result_id: builtins.int
    @property
    def check_result(self) -> global___CheckTextResult.CheckResult: ...
    def __init__(self,
        *,
        user_id: builtins.int = ...,
        check_result_id: builtins.int = ...,
        check_result: typing.Optional[global___CheckTextResult.CheckResult] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["check_result",b"check_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["check_result",b"check_result","check_result_id",b"check_result_id","user_id",b"user_id"]) -> None: ...
global___CheckTextResult = CheckTextResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class HashFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    CONTENT_HASH_FIELD_NUMBER: builtins.int
    WORDS_FIELD_NUMBER: builtins.int
    name: typing.Text
    url: typing.Text
    content_hash: typing.Text
    @property
    def words(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        name: typing.Text = ...,
        url: typing.Text = ...,
        content_hash: typing.Text = ...,
        words: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_hash",b"content_hash","name",b"name","url",b"url","words",b"words"]) -> None: ...
global___HashFile = HashFile



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0emessages.proto\x12\rkafka.message\"^\n\x0e\x41\x64\x64\x46ileRequest\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\x0c\n\x04hash\x18\x02 \x01(\t\x12\x10\n\x03url\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x11\n\tfull_path\x18\x04 \x01(\tB\x06\n\x04_url\"D\n\tCheckText\x12\x14\n\x0cis_google_on\x18\x01 \x01(\x08\x12\x10\n\x08\x64ocument\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\x03\"\xe8\x01\n\x0f\x43heckTextResult\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x17\n\x0f\x63heck_result_id\x18\x02 \x01(\x03\x12@\n\x0c\x63heck_result\x18\x03 \x01(\x0b\x32*.kafka.message.CheckTextResult.CheckResult\x1ai\n\x0b\x43heckResult\x12\x11\n\tfile_hash\x18\x01 \x01(\t\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x1d\n\x15plagiarism_percentage\x18\x03 \x01(\x01\x12\x15\n\rextended_data\x18\x04 \x01(\tB\x0cZ\n./messagesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'messages_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./messages'
  _ADDFILEREQUEST._serialized_start=33
  _ADDFILEREQUEST._serialized_end=127
  _CHECKTEXT._serialized_start=129
  _CHECKTEXT._serialized_end=197
  _CHECKTEXTRESULT._serialized_start=200
  _CHECKTEXTRESULT._serialized_end=432
  _CHECKTEXTRESULT_CHECKRESULT._serialized_start=327
  _CHECKTEXTRESULT_CHECKRESULT._serialized_end=432
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hashfiles.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fhashfiles.proto\x12\thashfiles\"J\n\x08HashFile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x14\n\x0c\x63ontent_hash\x18\x03 \x01(\t\x12\r\n\x05words\x18\x05 \x03(\tB\rZ\x0b./hashfilesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hashfiles_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\013./hashfiles'
  _HASHFILE._serialized_start=30
  _HASHFILE._serialized_end=104
# @@protoc_insertion_point(module_scope)
